@@ -17,25 +17,30 @@ Dialog::Dialog(QWidget *parent) :
 
 #ifdef Q_WS_HILDON
   this->setProperty("FingerScrollable", true);
-  ui->pbOK->setProperty("FingerScrollable", true);
 #endif
 
   QSettings *oSettings;
   oSettings = new QSettings("janbergmann", "simplenotewidget");
   QColor cldefault = oSettings->value("bgcolor", QColor(255,255,0)).value<QColor>();
   QColor cltextedit = oSettings->value("txtcolor", QColor(0,0,0)).value<QColor>();
-  int bgcoloralpha = oSettings->value("bgcoloralpha", int(180)).toInt();
-  cldefault.setAlpha(bgcoloralpha);
+
 
   int fontSizeIndex = oSettings->value("fontsize", int(3)).toInt();
   QString fontFamilyName = oSettings->value("fontfamily", "Nokia Sans SemiBold").toString();
 
 
   this->setWindowTitle("Edit note");
- // this->setWindowModality(Qt::ApplicationModal);
-  ui->teMain->setFrameShadow(QFrame::Plain);
-  ui->teMain->setFrameShape(QFrame::NoFrame);
-  ui->teMain->setPalette(QPalette(cltextedit,cldefault,cldefault,cltextedit,cltextedit,cltextedit,cldefault,cldefault,cldefault));
+
+  ui->teMain->setFrameShadow(QFrame::Sunken);
+  ui->teMain->setFrameShape(QFrame::StyledPanel);
+
+  this->setStyleSheet( "background-color: black ;" );
+  ui->teMain->setStyleSheet( "background-color: white ;" );
+  ui->pbOK->setStyleSheet( "background-color: grey ;" );
+  ui->pbCancel->setStyleSheet( "background-color: grey ;" );
+  ui->pbClear->setStyleSheet( "background-color: grey ;" );
+
+
   ui->teMain->setFontFamily(fontFamilyName);
   switch(fontSizeIndex)
   {
@@ -104,3 +109,9 @@ void Dialog::on_pbCancel_clicked()
 {
     this->close();
 }
+
+void Dialog::on_pbClear_clicked()
+{
+    ui->teMain->setText("");
+    ui->teMain->setFocus();
+}
