@@ -9,7 +9,9 @@
 #include <QMovie>
 #include <QDialog>
 #include <QSettings>
-
+#include <QVBoxLayout>
+#include <QScrollArea>
+#include <QWidget>
 
 
 #ifdef Q_WS_HILDON
@@ -27,30 +29,7 @@ MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(0, Qt::FramelessWindowHint),
     ui(new Ui::MainWindow)
 {
-#ifdef Q_WS_HILDON
-    QCoreApplication::instance()->setApplicationName("simplenotewidget");
-    // Get required atoms
-    Atom winTypeAtom = XInternAtom(QX11Info::display(), "_NET_WM_WINDOW_TYPE", false);
-    Atom homeAppletAto = XInternAtom(QX11Info::display(), "_HILDON_WM_WINDOW_TYPE_HOME_APPLET", false);
-    Atom appletIDAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_ID", false);
-    Atom utf8Atom = XInternAtom(QX11Info::display(), "UTF8_STRING", false);
-    Atom appletSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SETTINGS", false);
 
-    // Set correct window type
-    XChangeProperty(QX11Info::display(), winId(), winTypeAtom, XA_ATOM, 32,
-                    PropModeReplace, (unsigned char *) &homeAppletAto, 1);
-
-    // Use application name to fill AppletID
-    QByteArray id (QCoreApplication::instance()->applicationName().remove(' ').toUtf8());
-    XChangeProperty(QX11Info::display(), winId(), appletIDAtom, utf8Atom, 8,
-                    PropModeReplace, (unsigned char *)id.constData(), id.length());
-
-    // Add setting button. This button is shown when hildon-desktop is in edit mode.
-    int settings = 0;
-    XChangeProperty(QX11Info::display(), winId(), appletSettingAtom, XA_CARDINAL, 32,
-                    PropModeReplace, (unsigned char*)&settings, 1);
-
-#endif
     ui->setupUi(this);
     SetupThisUi();
 }
@@ -64,24 +43,13 @@ void MainWindow::showEvent(QShowEvent* event)
 }
 
 
-
-#ifdef Q_WS_HILDON
-    //Filter show setting requests
-    bool MainWindow::x11Event(XEvent* event)
-    {
-        static Atom appletShowSettingAtom = XInternAtom(QX11Info::display(), "_HILDON_APPLET_SHOW_SETTINGS", false);
-        if (event->xclient.message_type == appletShowSettingAtom )
-        {
-          settingsdlg *w;
-          w = new settingsdlg(0);
-          w->exec();
-          SetupThisUi();
-          //delete w;
-          return true;
-        }
-     return false;
-    }
-#endif
+void MainWindow::showSettingsDialog()
+{
+    settingsdlg *w;
+    w = new settingsdlg(0);
+    w->exec();
+    SetupThisUi();
+}
 
 
 
@@ -106,11 +74,30 @@ void MainWindow::SetupThisUi()
     oSettings = new QSettings("janbergmann", "simplenotewidget");
     QColor cldefault = oSettings->value("bgcolor", QColor(255,255,0)).value<QColor>();
     QColor cltextedit = oSettings->value("txtcolor", QColor(0,0,0)).value<QColor>();
-    int bgcoloralpha = oSettings->value("bgcoloralpha", int(180)).toInt();
-    cldefault.setAlpha(bgcoloralpha);
+    int bgcoloralpha = oSettings->value("bgcoloralpha", int(180)).toInt();   
     int fontSizeIndex = oSettings->value("fontsize", int(3)).toInt();
     QString fontFamilyName = oSettings->value("fontfamily", "Nokia Sans SemiBold").toString();
 
+
+
+    bool bSysColors = oSettings->value("syscolors", false).toBool();
+    if (bSysColors == true)
+    {
+        //QApplication::palette().color(QPalette::);
+        //QStyle CurrentStyle = QApplication::style();
+
+        cldefault  = QApplication::palette().color(QPalette::Background);
+        cltextedit = QApplication::palette().color(QPalette::Foreground);
+        QString SysFont =  QApplication::font().toString();
+
+
+
+    }
+
+    cldefault.setAlpha(bgcoloralpha);
+
+
+
     switch(fontSizeIndex)
     {
      case 0: fontSizeIndex = 6;
@@ -206,6 +193,12 @@ void MainWindow::SetupThisUi()
 
 }
 
+void MainWindow::paletteChange(const QPalette & oldPalette)
+{
+  Q_UNUSED( oldPalette );
+  this->setPalette( palette() );
+  SetupThisUi();
+}
 
 
 MainWindow::~MainWindow()
@@ -226,6 +219,3 @@ void MainWindow::changeEvent(QEvent *e)
 }
 
 
-
-
-
