@@ -19,10 +19,8 @@ protected:
     void changeEvent(QEvent *e);
     void showEvent(QShowEvent* event);
     bool eventFilter(QObject *o, QEvent *e );
+    void paletteChange(const QPalette & oldPalette);
 
-    #ifdef Q_WS_HILDON
-    bool x11Event ( XEvent * event );
-    #endif
 private:
     Ui::MainWindow *ui;
     void SetupThisUi();
@@ -30,6 +28,11 @@ private:
 
 private slots:
 
+
+private slots:
+
+public slots:
+   void showSettingsDialog();
 };
 
 #endif // MAINWINDOW_H
